diff --git lib/sasl/doc/src/sasl_app.xml lib/sasl/doc/src/sasl_app.xml
index 9c3c80b..a59573b 100644
--- lib/sasl/doc/src/sasl_app.xml
+++ lib/sasl/doc/src/sasl_app.xml
@@ -91,6 +91,12 @@
           <tag><c>{file,FileName}</c></tag>
           <item>Installs <c>sasl_report_file_h</c> in the error logger.
            This makes all reports go to the file <c>FileName</c>.
+          <tag><c>{file,FileName,Modes}</c></tag>
+          <item>Same as <c>{file,FileName}</c> except that the <c>Modes</c>
+           allows to specify the modes used for opening the <c>FileName</c>
+           given to the <seealso marker="kernel:file#open/2">file:open/2</seealso>
+           call. When not specified, the <c>Modes</c> defaults to <c>[write]</c>.
+           Use <c>[append]</c> for having the <c>FileName</c> open in append mode.
           <c>FileName</c> is a string.</item>
           <tag><c>false</c></tag>
           <item>
diff --git lib/sasl/src/sasl.erl lib/sasl/src/sasl.erl
index fdea6da..4a220f0 100644
--- lib/sasl/src/sasl.erl
+++ lib/sasl/src/sasl.erl
@@ -55,7 +55,9 @@ get_sasl_error_logger() ->
     case application:get_env(sasl, sasl_error_logger) of
 	{ok, false} -> undefined;
 	{ok, tty} -> tty;
-	{ok, {file, File}} when is_list(File) -> {file, File};
+	{ok, {file, File}} when is_list(File) -> {file, File, [write]};
+	{ok, {file, File, Modes}} when is_list(File), is_list(Modes) ->
+        {file, File, Modes};
 	{ok, Bad} -> exit({bad_config, {sasl, {sasl_error_logger, Bad}}});
 	_ -> undefined
     end.
@@ -125,9 +127,9 @@ delete_sasl_error_logger(Type) ->
     error_logger:delete_report_handler(mod(Type)).
 
 mod(tty) -> sasl_report_tty_h;
-mod({file, _File}) -> sasl_report_file_h.
+mod({file, _File, _Modes}) -> sasl_report_file_h.
 
-args({file, File}, Type) -> {File, type(Type)};
+args({file, File, Modes}, Type) -> {File, Modes, type(Type)};
 args(_, Type) -> type(Type).
 
 type(error) -> error;
diff --git lib/sasl/src/sasl_report_file_h.erl lib/sasl/src/sasl_report_file_h.erl
index f42b4b5..a5bd0ac 100644
--- lib/sasl/src/sasl_report_file_h.erl
+++ lib/sasl/src/sasl_report_file_h.erl
@@ -28,9 +28,9 @@
 	 handle_event/2, handle_call/2, handle_info/2,
 	 terminate/2]).
 
-init({File, Type}) ->
+init({File, Modes, Type}) when is_list(Modes) ->
     process_flag(trap_exit, true),
-    case file:open(File, [write]) of
+    case file:open(File, Modes) of
 	{ok,Fd} ->
 	    {ok, {Fd, File, Type}};
 	What ->
diff --git lib/sasl/test/sasl_SUITE.erl lib/sasl/test/sasl_SUITE.erl
index f4455f7..2c66057 100644
--- lib/sasl/test/sasl_SUITE.erl
+++ lib/sasl/test/sasl_SUITE.erl
@@ -29,7 +29,7 @@
 	 log_mf_h_env/1]).
 
 all() -> 
-    [log_mf_h_env, app_test, appup_test].
+    [log_mf_h_env, log_file, app_test, appup_test].
 
 groups() -> 
     [].
@@ -166,6 +166,24 @@ log_mf_h_env(Config) ->
     ok = application:set_env(sasl,error_logger_mf_dir,LogDir),
     ok = application:start(sasl).
 
+log_file(Config) ->
+    PrivDir = ?config(priv_dir,Config),
+    LogDir  = filename:join(PrivDir,sasl_SUITE_log_dir),
+    ok      = file:make_dir(LogDir),
+    File    = filename:join(LogDir, "file.log"),
+    application:stop(sasl),
+    SaslEnv = application:get_all_env(sasl),
+    lists:foreach(fun({E,_V}) -> application:unset_env(sasl,E) end, SaslEnv),
+
+    ok = application:set_env(sasl,sasl_error_logger,{file, File}),
+    ok = application:start(sasl),
+    true = filelib:is_file(File),
+
+    application:stop(sasl),
+    ok = application:set_env(sasl,sasl_error_logger,{file, File, [append]}),
+    ok = application:start(sasl),
+    true = filelib:is_file(File).
+
 
 %%-----------------------------------------------------------------
 %% Internal
